@@ -21,11 +21,7 @@ class AbstractHTTPClientFactory(ABC):
         self.session = session
 
     @abstractmethod
-    def create_with_default_middleware(self, credential: C) -> Session:
-        """Applies the default middleware chain to the HTTP Client"""
-
-    @abstractmethod
-    def create_with_custom_middleware(self, middleware: B) -> Session:
+    def create_with_custom_middleware(self, middleware: List[B]) -> Session:
         """Applies the custom middleware chain to the HTTP Client"""
 
         raise NotImplementedError("create_with_custom_middleware is not implemented")
