@@ -11,15 +11,39 @@ class OptionsCollection(TypeCollection[O]):
     """Option Collection Type"""
 
     def __getitem__(self, index: int) -> Option:
+        """Gets object at index
+        """
+        
+        """Gets object at index
+        """
+        
         return self._internal_list[index]
 
     def __len__(self) -> int:
+        """gets the length of the collection
+        """
+        
+        """gets the length of the collection
+        """
+        
         return len(self._internal_list)
 
     def __delitem__(self, index: int) -> None:
+        """Deletes object at index
+        """
+        
+        """Deletes object at index
+        """
+        
         del self._internal_list[index]
 
     def __setitem__(self, index: int, value: O) -> None:
+        """Sets object at index
+        """
+        
+        """Sets object at index
+        """
+        
         self._internal_list[index] = value
 
     def as_dict(self) -> Dict[str, Any]:
